@@ -15,7 +15,7 @@ impl GenericNode<LogicalType> for EqualNode {
         let right_node = self.right_child.as_ref().ok_or(
             CalculationError::new("The right child of an equal node must be present to perform a calculation")
         )?;
-        Ok(left_node.calculate(Some(parameters))? == right_node.calculate(Some(parameters))?)
+        Ok(left_node.calculate_wrapped_nodes(parameters)? == right_node.calculate_wrapped_nodes(parameters)?)
     }
 }
 
@@ -24,10 +24,12 @@ impl ArithmeticResultNodeWrapper {
         LogicalResultNodeWrapper{
             node: Some(
                 Node::EqualNode(
-                    EqualNode{
-                        left_child: Some(self),
-                        right_child: Some(node)
-                    }
+                    Box::new(
+                        EqualNode{
+                            left_child: Some(Box::new(self)),
+                            right_child: Some(Box::new(node))
+                        }
+                    )
                 )
             )
         }
